.. spacetrack documentation master file

spacetrack documentation
========================

``spacetrack`` is a Python client for `Space-Track`_, with methods for all
request classes, keyword validation for request predicates, streaming download
support, and automatic rate limiting.

.. _`Space-Track`: https://www.space-track.org/

Contents:

.. toctree::
   :maxdepth: 3

   installation
   usage
   module
   changelog

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
